@@ -15,6 +15,7 @@ from . import click_types
 from . import gitlab
 from . import lando
 from . import util
+from . import composer
 
 
 DEFAULT_CORE_VERSION = "^8.9.0"
@@ -58,10 +59,17 @@ DEFAULT_CORE_VERSION = "^8.9.0"
     show_default=True,
 )
 @click.option(
-    "--docroot", help="The document root", type=click.Path(exists=False), default="web"
+    "--module",
+    "--package",
+    "-m",
+    "-p",
+    "packages",
+    type=click_types.COMPOSER_PACKAGE,
+    help="Specify Drupal module names or PHP packages",
+    multiple=True,
 )
 @click.option(
-    "--no-install", help="Do not run composer install", is_flag=True, default=False
+    "--docroot", help="The document root", type=click.Path(exists=False), default="web"
 )
 @click.option(
     "--cache",
@@ -77,13 +85,13 @@ DEFAULT_CORE_VERSION = "^8.9.0"
     is_flag=True,
 )
 def main(
-    name: util.ComposerVersion,
+    name: composer.ComposerVersion,
     directory,
     description,
     core_package,
     core_version,
+    packages,
     docroot,
-    no_install,
     cache,
     add_lando,
     add_gitlab,
@@ -95,7 +103,7 @@ def main(
     Create a Drupal site template with NAME.
     Where NAME is the name of your application package (e.g., axelerant/site)
     """
-    if not no_install:
+    if not composer.is_version_2():
         ensure_memory_limit()
 
     if directory == "":
@@ -114,14 +122,13 @@ def main(
         cache_service=cache,
     )
 
-    if not no_install:
-        run_composer_install()
-    else:
-        util.write_info("Remember to run 'composer install' manually.")
+    composer.run_install()
+    composer.require_packages(packages)
 
     settings_file = ensure_settings_file(docroot)
     modify_settings_file(
-        settings_file, "$settings['config_sync_directory'] = '../config/sync';",
+        settings_file,
+        "$settings['config_sync_directory'] = '../config/sync';",
     )
 
     write_settings_env(docroot)
@@ -143,7 +150,6 @@ def ensure_memory_limit():
     """
     if shutil.which("php") is None:
         util.write_error("Cannot find php.")
-        util.write_error("Run with --no-install flag if you don't need composer.")
         sys.exit(3)
 
     mem_limit = os.getenv("COMPOSER_MEMORY_LIMIT")
@@ -202,38 +208,17 @@ def prepare_base_directory(directory, force):
     try:
         for file in files_to_del:
             util.write_warning(f'Removing "{file}"...')
-            if os.path.isdir(file):
-                shutil.rmtree(file)
+            path = f"./{directory}/{file}"
+            if os.path.isdir(path):
+                shutil.rmtree(path)
             else:
-                os.remove(file)
+                os.remove(path)
     except OSError as err:
         util.write_error(f'Failed deleting files in the "{directory}" directory')
         util.write_error(str(err))
         sys.exit(2)
 
 
-def run_composer_install():
-    """
-    Run composer install and handle errors
-    """
-    if shutil.which("composer") is None:
-        util.write_error("Cannot find composer. Aborting...")
-        sys.exit(4)
-
-    composer_run = subprocess.run(
-        "composer install --ignore-platform-reqs -o", shell=True, check=False
-    )
-    if composer_run.returncode != 0:
-        util.write_error("Error when running 'composer install'. Aborting...")
-        util.write_error("Make sure you have set an adequate PHP memory limit.")
-        util.write_warning(
-            "Read {} for more details".format(
-                "https://getcomposer.org/doc/articles/troubleshooting.md#memory-limit-errors"
-            )
-        )
-        sys.exit(4)
-
-
 def generate_drupal_files(
     name,
     description="",
@@ -245,7 +230,7 @@ def generate_drupal_files(
     """
     Generate Drupal files based on the given options
     """
-    composer = get_composer_template(
+    composer_template = composer.get_drupal_template(
         name=name,
         description=description,
         core=core,
@@ -253,16 +238,20 @@ def generate_drupal_files(
         docroot=docroot,
         cache_service=cache_service,
     )
-    composer = sort_composer_packages(composer)
+    composer_template = composer.sort_packages(composer_template)
     with open("composer.json", "w") as composer_file:
-        json.dump(composer, composer_file, indent=4)
+        json.dump(composer_template, composer_file, indent=4)
     util.write_file(".gitignore", get_gitignore(docroot))
 
     util.copy_package_file("files/drupal/load.environment.php", "load.environment.php")
     util.copy_package_file("files/drupal/.env.example", ".env.example")
 
     os.makedirs("drush/sites", mode=0o755, exist_ok=True)
-    util.copy_package_file("files/drupal/drush.yml", "drush/drush.yml")
+
+    drush_yml = util.read_package_file("files/drupal/drush.yml")
+    drush_yml = drush_yml.replace("{name}", name)
+    util.write_file("drush/drush.yml", drush_yml)
+
     util.copy_package_file("files/drupal/self.site.yml", "drush/sites/self.site.yml")
 
     os.makedirs("config/sync", mode=0o755, exist_ok=True)
@@ -277,58 +266,6 @@ def generate_drupal_files(
     util.copy_package_file("files/drupal/renovate.json", "renovate.json")
 
 
-def get_composer_template(
-    name, description, core, core_version, docroot, cache_service
-):
-    """
-    Get the composer template from package and modify it as per given options
-    """
-    composer = json.loads(pkgutil.get_data(__name__, "files/drupal/composer.json"))
-    composer["name"] = name
-    composer["description"] = description
-    composer["extra"]["drupal-scaffold"]["locations"]["web-root"] = docroot + "/"
-    composer["extra"]["installer-paths"] = {
-        docroot + "/core": ["type:drupal-core"],
-        docroot + "/libraries/{$name}": ["type:drupal-library"],
-        docroot + "/modules/contrib/{$name}": ["type:drupal-module"],
-        docroot + "/profiles/contrib/{$name}": ["type:drupal-profile"],
-        docroot + "/themes/contrib/{$name}": ["type:drupal-theme"],
-        "drush/Commands/contrib/{$name}": ["type:drupal-drush"],
-        docroot + "/modules/custom/{$name}": ["type:drupal-custom-module"],
-        docroot + "/themes/custom/{$name}": ["type:drupal-custom-theme"],
-    }
-
-    if core == "core":
-        composer["require"]["drupal/core"] = core_version
-    if core == "recommended":
-        composer["require"]["drupal/core-recommended"] = core_version
-    if cache_service == "redis":
-        composer["require"]["drupal/redis"] = "^1.4"
-    if cache_service == "memcache":
-        composer["require"]["drupal/memcache"] = "^2.0"
-    composer["require"]["drupal/core-composer-scaffold"] = core_version
-    return composer
-
-
-def sort_composer_packages(composer):
-    """
-    Sort the packages in a composer array
-    """
-    composer["require"] = sort_dictionary_by_keys(composer["require"])
-    composer["require-dev"] = sort_dictionary_by_keys(composer["require-dev"])
-    return composer
-
-
-def sort_dictionary_by_keys(input_dict):
-    """
-    Sort the dictionary by keys in alphabetical order
-    """
-    sorted_dict = {}
-    for key in sorted(input_dict.keys()):
-        sorted_dict[key] = input_dict[key]
-    return sorted_dict
-
-
 def get_gitignore(docroot):
     """
     Get gitignore template from the package
